Coverage for /home/tribaal/workspace/django-shop/shop/__init__: 100.00%

# Coverage for /home/tribaal/workspace/django-shop/shop/__init__ : 100.00%

## 2 statements 2 run 0 missing 0 excluded 0 partial

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 | # -*- coding: utf-8 -*- """ See PEP 386 (http://www.python.org/dev/peps/pep-0386/) Release logic: 1. Remove "dev" from current. 2. git commit 3. git tag <version> 4. push to pypi + push to github 5. bump the version, append '.dev0' 6. git commit 7. push to github (to avoid confusion) """ __version__ = '0.1.2.dev0'